function ModelParameters = LPTSteadyStateParameters(ModelParameters)
% LPTSteadyStateParameters: Shows how to compute the updated parameters in Leeper, Plante and Traum (2010)
%
% USAGE:
%
%       ModelParameters = LPTSteadyStateParameters(ModelParameters)
%
% REQUIRED INPUT:  ModelParameters (structure) with fields corresponding to the parameters
%                                   you need for defining new parameters that should be
%                                   added to the structure.
%
% REQUIRED OUTPUT: ModelParameters (structure) with additions to the input structure.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: July 15, 2015.
%                        This version: January 15, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 16-07-2015: Updated the documentation.
%
% * 21-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 15-01-2018: Updated the documentation.
%
% * 21-01-2019: Updated the documentation.
%
% * 08-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 04-01-2023: Updated the documentation.
%
% * 15-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Steady-state parameters as functions of the estimated parameters kappa, h, and gamma in Leeper, Plante and Traum (2010, JoEconometrics)
%

ModelParameters.L = ( ( (1-ModelParameters.taul)*(1-ModelParameters.alpha)*( ( ModelParameters.alpha/ModelParameters.Rk )^(((1-ModelParameters.gamma)*ModelParameters.alpha)/(1-ModelParameters.alpha)) ) )/( (1+ModelParameters.tauc)*( ( (1-ModelParameters.h)*(1-ModelParameters.sg-((ModelParameters.delta0*ModelParameters.alpha)/ModelParameters.Rk)) )^ModelParameters.gamma  )  ) )^(1/(ModelParameters.kappa+ModelParameters.gamma));
ModelParameters.C = (1-ModelParameters.sg-((ModelParameters.delta0*ModelParameters.alpha)/ModelParameters.Rk))*( (ModelParameters.alpha/ModelParameters.Rk)^(ModelParameters.alpha/(1-ModelParameters.alpha)) )*ModelParameters.L;
ModelParameters.K = ( ( ModelParameters.alpha/ModelParameters.Rk )^(1/(1-ModelParameters.alpha)) )*ModelParameters.L;
ModelParameters.Y = ( ( ModelParameters.alpha/ModelParameters.Rk )^(ModelParameters.alpha/(1-ModelParameters.alpha)) )*ModelParameters.L;
ModelParameters.I = ModelParameters.delta0*ModelParameters.K;
ModelParameters.Z = (ModelParameters.tauk*ModelParameters.alpha*ModelParameters.Y) + (ModelParameters.taul*(1-ModelParameters.alpha)*ModelParameters.Y) + (ModelParameters.tauc*ModelParameters.C) - ((ModelParameters.sg+(((1-ModelParameters.beta)/ModelParameters.beta)*ModelParameters.sb))*ModelParameters.Y);
ModelParameters.G = ModelParameters.sg*ModelParameters.Y;
ModelParameters.B = ModelParameters.sb*ModelParameters.Y;

%
% end of LPTSteadyStateParameters.m
%
