function status = DirExist(Directory)
% DirExist: Checks if directory exists.
%
% USAGE:
%
%       status = DirExist(Directory)
%
% where Directory is the full path. If the directory exists then DirExist returns 1, otherwise 0.
%
% REQUIRED INPUTS: Directory (string) with full path (e.g. c:\code\yada)
%
% REQUIRED OUTPUT: status (boolean) is 1 if the directory exists and 0 otherwise.
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: July 20, 2006.
%                        This version: January 15, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 08-12-2008: Updated the documentation.
%
% * 02-05-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 09-01-2011: The function can now handle unix and mac directories.
%
% * 03-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 21-01-2016: Updated the documentation.
%
% * 20-03-2017: Updated the documentation.
%
% * 16-01-2018: Updated the documentation.
%
% * 22-01-2019: Updated the documentation.
%
% * 09-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 04-01-2023: Updated the documentation.
%
% * 15-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

status = 0;
if nargin==0;
   return;
end;
if ischar(Directory)==0;
   return;
end;
if isunix==1;
   Directory = strrep(Directory,'\','/');
end;
d = dir(Directory);
if (isempty(d)==0)&(min(size(d))>=1);
   status = 1;
end;

%
% end of DirExist.m
%
