function outtext = ReadText(file)
% ReadText: Reads the contents of a text file.
%
% USAGE:
%
%       outtext = ReadText(file)
%
% REQUIRED INPUTS: file (string) with full path+name+extension of file (e.g. c:\code\myfile.txt)
%                       Any type of file, including binary files, can be checked by the function.
%
% REQUIRED OUTPUT: outtext (cell string) with as many elements as there are rows in file. If the file
%                       is either a binary file, does not exist, or is empty, then ReadText returns
%                       and empty string.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: July 18, 2006.
%                        This version: January 15, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 19-7-2006:  Updated function information.
%
% * 13-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 08-12-2008: Updated the documentation.
%
% * 02-05-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 09-01-2011: The function can now read text files on unix and mac computers.
%
% * 03-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 21-01-2016: Updated the documentation.
%
% * 20-03-2017: Updated the documentation.
%
% * 16-01-2018: Updated the documentation.
%
% * 22-01-2019: Updated the documentation.
%
% * 09-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 04-01-2023: Updated the documentation.
%
% * 15-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if isunix==1;
   file = strrep(file,'\','/');
end;
outtext = '';
fid = fopen(file,'rt');
if fid>-1;
   fileline = fgetl(fid);
   num = 1;
   out = '';
   while isnumeric(fileline)==0;
      if strcmp(fileline,'')==0;
         if strcmp(out,'')==1;
            out = 'alina';
         end;
         outtext{num} = fileline;
         num = num+1;
      else;
         outtext{num} = '';
         num = num+1;
      end;
      fileline = fgetl(fid);
   end;
   fclose(fid);
end;

%
% end of ReadText.m
%
