function SetFigureProperties(FigureHandle,CurrINI)
% SetFigureProperties: Sets a number of figure properties
%
% USAGE:
%
%       SetFigureProperties(FigureHandle,CurrINI)
%
% REQUIRED INPUTS: FigureHandle (handle) to a matlab figure.
%
%                  CurrINI (structure) with initialization information.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: 15 August, 2006.
%                        This version: January 8, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 23-08-2007: Updated the documentation.
%
% * 09-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 19-12-2008: Updated the documentation.
%
% * 02-05-2009: Updated the documentation.
%
% * 06-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 03-01-2012: Updated the documentation.
%
% * 02-01-2013: Updated the documentation.
%
% * 24-01-2014: Updated the documentation.
%
% * 05-01-2015: Updated the documentation.
%
% * 18-03-2015: Switched to the new IsHandle function.
%
% * 08-06-2015: The code takes the CurrINI.GraphicsRoot field into account.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 08-01-2018: Updated the documentation.
%
% * 21-01-2019: Updated the documentation.
%
% * 07-01-2020: Updated the documentation.
%
% * 25-01-2021: Updated the documentation.
%
% * 03-01-2022: Updated the documentation.
%
% * 03-01-2023: Updated the documentation.
%
% * 08-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if CurrINI.landscape==1;
   orientstr = 'landscape';
else;
   orientstr = 'portrait';
end;
if CurrINI.invert_hardcopy==1;
   inv_hardcopy = 'on';
else;
   inv_hardcopy = 'off';
end;
if CurrINI.z_buffer==1;
   renderer = 'zbuffer';
else;
   renderer = 'painters';
end;
%
% setting the current figure properties
%
if IsHandle(FigureHandle)==1;
   set(FigureHandle,'Color',get(CurrINI.GraphicsRoot,'defaultuicontrolbackgroundcolor'), ...
         'NumberTitle','off', ...
         'Renderer',renderer, ...
         'PaperUnits',CurrINI.paperunits, ...
         'PaperOrientation',orientstr, ...
         'PaperPositionMode',CurrINI.paperposmode, ...
         'PaperType',CurrINI.papertype, ...
         'InvertHardcopy',inv_hardcopy);
   %
   if MatlabNumber>=7.0;
      set(FigureHandle,'DockControl','off');
   end;
   %
   % obey centering and filling defaults
   %
   CenterFillFigure(FigureHandle,CurrINI.fill_value,CurrINI.center_value);
end;

%
% end of SetFigureProperties.m
%
