function status = CheckAdaptiveLearningFixedBeliefs(ModelParameters)
% CheckAdaptiveLearningFixedBeliefs: The function checks if all adaptive learning parameters are equal to zero.
%
% USAGE:
%
%       status = CheckAdaptiveLearningFixedBeliefs(ModelParameters)
%
% REQUIRED INPUT:  ModelParameters (structure) with fields including sigmaeAL, sigmarAL and rhoAL.
%
% REQUIRED OUTPUT: status (boolean) that takes on the value 1 if all three adaptive learning
%                         parameters are zero and 0 otherwise. The former means that the belief
%                         coefficients are fixed at their initial values.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: October 24, 2023.
%                        This version: March 13, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 25-10-2023: Updated the documentation.
%
% * 13-03-2023: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

status = 0;
if (ModelParameters.sigmaeAL<=1.0e-8)&(ModelParameters.sigmarAL<=1.0e-8)&(abs(ModelParameters.rhoAL)<=1.0e-8);
   status = 1;
end;

%
% end of CheckAdaptiveLearningFixedBeliefs.m
%
