function A = VerifyVector(A,n)
% VerifyVector: Removes any elements in A that are greater than n or less than or equal to 0. Only unique
%               integers are kept and sorted.
%
% USAGE:
%
%       A = VerifyVector(A,n)
%
% REQUIRED INPUT:  A (n1x1) vector where n1<=n with integer values
%
%                  n (integer) taking a positive value.
%
% REQUIRED OUTPUT: A (n2x1) vector with the elements of A that are greater than 0
%                    and less than or equal to n.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: January 12, 2007.
%                        This version: January 16, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 18-12-2008: Updated the documentation.
%
% * 03-05-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 04-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 15-08-2014: Made sure only unique values are kept and that they are sorted from
%               the smallest to the largest.
%
% * 14-01-2015: Updated the documentation.
%
% * 22-01-2016: Updated the documentation.
%
% * 21-03-2017: Updated the documentation.
%
% * 17-01-2018: Updated the documentation.
%
% * 22-01-2019: Updated the documentation.
%
% * 09-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 05-01-2022: Updated the documentation.
%
% * 05-01-2023: Updated the documentation.
%
% * 16-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

A = sort(unique(floor(A)));
A = A(A<=n);
A = A(A>0);

%
% end of VerifyVector.m
%
