function controls = EditMenuControls(maingui,controls)
% EditMenuControls: sets up the Edit menu.
%
% USAGE:
%
%       controls = EditMenuControls(maingui,controls)
%
% REQUIRED INPUT:  maingui (handle) to YADA's main dialog.
%
%                  controls (structure) with handles to the controls on the YADA main dialog.
%
% REQUIRED OUTPUT: controls (structure) with handles to the controls on the YADA main dialog.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: March 3, 2010.
%                        This version: January 18, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 04-03-2010: Updated the documentation.
%
% * 07-03-2010: Changed the cases of the callback indicator from all lower case
%               to mixed upper and lower case.
%
% * 05-01-2011: Updated the documentation.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
% * 15-09-2017: Updated the documentation.
%
% * 08-01-2018: Updated the documentation.
%
% * 23-01-2019: Updated the documentation.
%
% * 10-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 05-01-2023: Updated the documentation.
%
% * 18-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Edit menu
%
controls.editmenu = uimenu('Parent',maingui, ...
   'Label','&Edit', ...
   'Tag','EditMenu');
%
% Objects on the Edit menu
%
controls.editundomenu = uimenu('Parent',controls.editmenu, ...
   'Label','&Undo', ...
   'Callback','EditMenuFunctions EditUndo', ...
   'Accelerator','Z', ...
   'Enable','on', ...
   'Tag','EditUndoMenu');
%
controls.editcutmenu = uimenu('Parent',controls.editmenu, ...
   'Label','Cu&t', ...
   'Callback','EditMenuFunctions EditCut', ...
   'Accelerator','X', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','EditCutMenu');
%
controls.editcopymenu = uimenu('Parent',controls.editmenu, ...
   'Label','&Copy', ...
   'Callback','EditMenuFunctions EditCopy', ...
   'Accelerator','C', ...
   'Enable','on', ...
   'Tag','EditCopyMenu');
%
controls.editpastemenu = uimenu('Parent',controls.editmenu, ...
   'Label','&Paste', ...
   'Callback','EditMenuFunctions EditPaste', ...
   'Accelerator','V', ...
   'Enable','on', ...
   'Tag','EditPasteMenu');
%
controls.editselectallmenu = uimenu('Parent',controls.editmenu, ...
   'Label','Select &All', ...
   'Callback','EditMenuFunctions EditSelectAll', ...
   'Accelerator','A', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','EditSelectAllMenu');

%
% end of EditMenuControls.m
%
