function z = MultiStudentTRndFcn(mu,CholSigma,d,NumDraws)
% MultiStudentTRndFcn: Draws a matrix of random data from a multivariate Student t distribution.
%
% USAGE:
%
%       z = MultiStudentTRndFcn(mu,CholSigma,d,NumDraws)
%
% REQUIRED INPUT:  mu (vector) of dimension n with location parameter of the multivariate Student t distribution.
%
%                  CholSigma (matrix) of dimension nxn with the Choleski decomposition of the Sigma scale matrix
%                            of the multivariate student t.
%
%                  d (integer) with the number of degrees of freedom.
%
% OPTIONAL INPUT:  NumDraws (integer) with the number of draws.
%
% REQUIRED OUTPUT: z (matrix) of dimension nxNumDraws with draws from the multivarate Student-t
%                    distribution.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2024 European Central Bank.
%
%                       First version: August 25, 2015.
%                        This version: January 19, 2024.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 26-08-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 29-03-2017: Updated the documentation.
%
% * 15-05-2018: Updated the documentation.
%
% * 24-01-2019: Updated the documentation.
%
% * 10-01-2020: Updated the documentation.
%
% * 26-01-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 06-01-2023: Updated the documentation.
%
% * 19-01-2024: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%if nargin==0;
%   mu = zeros(3,1);
%   CholSigma = eye(3);
%   d = 30;
%   NumDraws = 500;
%end;
if nargin==3;
   NumDraws = 1;
end;
NumDraws = floor(NumDraws);
if NumDraws<1;
   NumDraws = 1;
end;
%
n = length(mu);
%z = (mu*ones(1,NumDraws))+(CholSigma*randn(n,NumDraws).*(ones(n,1)*sqrt(InvGamma2RndFcn(d,d,NumDraws)')));
z = (mu*ones(1,NumDraws))+(CholSigma*randn(n,NumDraws).*(ones(n,1)*sqrt(d./GammaRndFcn(d/2,2,NumDraws))));
%meanZ = sum(z,2)/NumDraws;
%Z = z-(meanZ*ones(1,NumDraws));
%covZ = Z*Z'/NumDraws;
%disp(meanZ);
%disp(covZ);
%disp((d/(d-2))*CholSigma*CholSigma');

%
% end of MultiStudentTRndFcn.m
%
